/**
 * Core component configuration for prompt template sections.
 * Defines the structure and behavior of individual prompt components
 * including constraints, examples, and various thinking approaches.
 *
 */
interface PromptTemplateComponent {
    /**
     * Input data for the propmt component, add variables here like so {{variable}}
     */
    text: string;
    /**
     * Response limitations/requirements
     */
    constraints: string[];
    /**
     * Few-shot learning examples
     */
    examples: {
        input: string | Record<string, any>;
        output: string | Record<string, any>;
    }[];
    /**
     * Cognitive enhancement configurations
     */
    thinking: {
        /**
         * Step-by-step reasoning
         */
        autoChainOfThought?: boolean;
        /**
         * Multiple approach exploration
         */
        autoTreeOfThought?: boolean;
        /**
         * Self-questioning mechanism
         */
        autoSelfAsk?: boolean;
        /**
         * Solution verification
         */
        autoVerification?: boolean;
        /**
         * Explicit reasoning steps
         */
        steps?: string[];
        /**
         * Tree-of-thought branches
         */
        branches?: {
            [key: string]: string[];
        };
        /**
         * Verification process steps
         */
        verificationSteps?: string[];
    };
    /**
     * Emphasis configurations
     */
    emphasis: {
        type: 'IMPORTANT !!!';
    } | {
        type: 'CALLOUT';
    } | {
        type: 'CUSTOM';
        text: string;
    };
    /**
     * Contextual information
     */
    context: string;
}
/**
 * Configuration for prompt template construction.
 * Supports various prompting techniques and formatting options
 * that have shown to improve model performance in research.
 */
interface PromptTemplateConstructor {
    /**
     * Professional role/persona to guide response style
     */
    persona?: string;
    /**
     * Response style (analytical, creative, etc.)
     */
    style?: string;
    /**
     * Communication tone affecting response formality
     */
    tone?: string;
    /**
     * Output structure specification
     */
    outputFormat?: string;
    /**
     * Point of view for response
     */
    perspective?: string;
    /**
     * Message role designation
     */
    as?: 'system' | 'user';
}
export declare class PromptTemplate<TVariables extends Record<string, any> | undefined = undefined> {
    private intent;
    private config;
    private components;
    constructor(intent: string, config?: PromptTemplateConstructor);
    text(text: PromptTemplateComponent['text']): this;
    constraints(constraints: PromptTemplateComponent['constraints']): this;
    examples(examples: PromptTemplateComponent['examples']): this;
    thinking(config: PromptTemplateComponent['thinking']): this;
    emphasis(emphasis: PromptTemplateComponent['emphasis']): this;
    context(context: PromptTemplateComponent['context']): this;
    private buildPromptComponent;
    get layout(): {
        intro: string[];
        outro: string[];
    };
    toString(variables?: TVariables): string;
    toMessage(variables?: TVariables): {
        role: "system" | "user";
        content: string;
    };
}
export declare function createPrompt<TVariables extends Record<string, any> | undefined = undefined>(intent: string, config?: PromptTemplateConstructor): PromptTemplate<TVariables>;
export {};
//# sourceMappingURL=index.d.ts.map